#!/usr/bin/env python
# -*- coding: utf-8 -*-
import dbus
from ve_utils import convert_vreg_version_to_readable

## @package dbus_vrm
# convers the values as shown on the D-Bus to the format as expected by VRM


class Conversions():

	@classmethod
	def convert(cls, code, value):
		if code in ['H9']:
			# Convert seconds to days
			return value / 86400
		elif code in ['TTG', 'bt']:
			# Convert seconds to hours
			return value / 3600
		elif code in ['BV', 'ScVt', 'liV', 'cF']:
			# convert firmware version to readable version string
			return convert_vreg_version_to_readable(value)
		elif code in ['BM', 'ScM', 'liM', 'pM', 'cP']:
			# Convert value to Hex, mostly firmware versions and productids
			return "%x" % value
		elif code in ['Alarm', 'SceA', 'SceL', 'SceH']:
			# Note that not all alarms on VRM have only 0 = OK and 1 = Alarm. VEBus do have 0=OK, 1=Warning,
			# 2=Alarm. But BMV etc (that doesn't have warnings) has always had only 0 and 1. And on the D-Bus
			# it does use the same enum as VEBus. To make VRM the same, we will run a large query on the database
			# someday to update all existing data...
			return value if value != 2 else 1
		elif code in ['vvv', 'vvp']:
			# convert decimal to bsd notation.
			return int(hex(int(value))[2:])
		else:
			return value
